%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% Written by Sun Xu, Kim Chee Wee, B. Kannan & Francois Chin on 14/09/2004 
%
% Modified for 802.15.3c by Rick Roberts, 1 August 2006
%
% Loads the modified S-V model parameters for TG3c channel models
%--------------------------------------------------------------------------
% n                 Path Loss Exponent
% PLo               Free Space Path Loss at Reference Distance 
% LowSigma_s        Standard Deviation of Path Loss Shadowing
% CapLambda         Cluster arrival rate (clusters per nsec)
% LowLambda         Ray arrival rate (rays per nsec)
% CapGamma          Cluster Decay Factor
% LowGamma          Ray Decay Factor
% LowSigma_c        Standard Deviation of Cluster Lognormal Fading Term (dB)
% LowSigma_r        Standard Deviation of Ray Lognormal Fading Term (dB)
% LowSignma_phi     Standard Deviation of the Ray Angle of Arrival
% L_mean            Mean number of Clusters
% Delta_CapK        LOS Rician Factor
% Delta_LowK        Cluster First Ray Factor
% CapOmega          Average Power of the First Ray of the First Cluster
% h1                Height of TX Antenna
% h2                Height of RX Antenna
% G_T               Gain of TX Antenna
% G_R               Gain of RX Antenna
% fs                Sampling Rate
% CapK_los          LOS K Factor
% nlos              Flag for non line of sight channel
%                       0 -> LOS
%                       1 -> NLOS with first arrival path starting at t ~= 0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% ParamStore definition:
%
% ParamStore(cm_num, ... 24 S-V parameters ...)
%
% dimensions: ParamStore (9, 24)
%
% ParamStore(cm_num, 1) <-- n
% ParamStore(cm_num, 2) <-- PLo
% ParamStore(cm_num, 3) <-- LowSigma_s
% ParamStore(cm_num, 4) <-- CapLambda
% ParamStore(cm_num, 5) <-- LowLambda
% ParamStore(cm_num, 6) <-- CapGamma
% ParamStore(cm_num, 7) <-- LowGamma
% ParamStore(cm_num, 8) <-- LowSigma_c
% ParamStore(cm_num, 9) <-- LowSigma_r
% ParamStore(cm_num, 10) <-- LowSigma_phi
% ParamStore(cm_num, 11) <-- L_mean
% ParamStore(cm_num, 12) <-- Delta_CapK
% ParamStore(cm_num, 12) <-- Delta_LowK
% ParamStore(cm_num, 13) <-- CapOmega
% ParamStore(cm_num, 14) <-- h1
% ParamStore(cm_num, 15) <-- h2
% ParamStore(cm_num, 16) <-- G_T
% ParamStore(cm_num, 17) <-- G_R
% ParamStore(cm_num, 18) <-- fs
% ParamStore(cm_num, 19) <-- CapK_los
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cm_num=1.1; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/5.24; % CapLambda
  ParamStore(10*cm_num, 5)= 1/0.82; % LowLambda
  ParamStore(10*cm_num, 6)= 4.46; % CapGamma
  ParamStore(10*cm_num, 7)= 6.25; % LowGamma
  ParamStore(10*cm_num, 8)= 6.28; % LowSigma_c
  ParamStore(10*cm_num, 9)= 13.0; % LowSigma_r
  ParamStore(10*cm_num, 10)= 49.8; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 9; % L_mean
  ParamStore(10*cm_num, 12)= NaN; % Delta_CapK
  ParamStore(10*cm_num, 12)= 18.8; % Delta_LowK
  ParamStore(10*cm_num, 13)= -88.7; % CapOmega
  ParamStore(10*cm_num, 14)= NaN; % h1
  ParamStore(10*cm_num, 15)= NaN; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
cm_num=1.2; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/5.15; % CapLambda
  ParamStore(10*cm_num, 5)= 1/1.11; % LowLambda
  ParamStore(10*cm_num, 6)= 8.98; % CapGamma
  ParamStore(10*cm_num, 7)= 9.17; % LowGamma
  ParamStore(10*cm_num, 8)= 6.63; % LowSigma_c
  ParamStore(10*cm_num, 9)= 9.83; % LowSigma_r
  ParamStore(10*cm_num, 10)= 119; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 11; % L_mean
  ParamStore(10*cm_num, 12)= NaN; % Delta_CapK
  ParamStore(10*cm_num, 12)= 17.4; % Delta_LowK
  ParamStore(10*cm_num, 13)= -108; % CapOmega
  ParamStore(10*cm_num, 14)= NaN; % h1
  ParamStore(10*cm_num, 15)= NaN; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
cm_num=1.3; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/6.94; % CapLambda
  ParamStore(10*cm_num, 5)= 1/0.856; % LowLambda
  ParamStore(10*cm_num, 6)= 21.5; % CapGamma
  ParamStore(10*cm_num, 7)= 4.35; % LowGamma
  ParamStore(10*cm_num, 8)= 3.71; % LowSigma_c
  ParamStore(10*cm_num, 9)= 7.31; % LowSigma_r
  ParamStore(10*cm_num, 10)= 46.2; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 8; % L_mean
  ParamStore(10*cm_num, 12)= NaN; % Delta_CapK
  ParamStore(10*cm_num, 12)= 11.9; % Delta_LowK
  ParamStore(10*cm_num, 13)= -111; % CapOmega
  ParamStore(10*cm_num, 14)= NaN; % h1
  ParamStore(10*cm_num, 15)= NaN; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
cm_num=1.4; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/22.2; % CapLambda
  ParamStore(10*cm_num, 5)= 1/1.08; % LowLambda
  ParamStore(10*cm_num, 6)= 12.6; % CapGamma
  ParamStore(10*cm_num, 7)= 4.98; % LowGamma
  ParamStore(10*cm_num, 8)= 7.34; % LowSigma_c
  ParamStore(10*cm_num, 9)= 6.11; % LowSigma_r
  ParamStore(10*cm_num, 10)= 107; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 4; % L_mean
  ParamStore(10*cm_num, 12)= NaN; % Delta_CapK
  ParamStore(10*cm_num, 12)= 4.60; % Delta_LowK
  ParamStore(10*cm_num, 13)= -110.7; % CapOmega
  ParamStore(10*cm_num, 14)= NaN; % h1
  ParamStore(10*cm_num, 15)= NaN; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
cm_num=1.5; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/4.76; % CapLambda
  ParamStore(10*cm_num, 5)= 1/1.30; % LowLambda
  ParamStore(10*cm_num, 6)= 4.19; % CapGamma
  ParamStore(10*cm_num, 7)= 1.07; % LowGamma
  ParamStore(10*cm_num, 8)= 1.54; % LowSigma_c
  ParamStore(10*cm_num, 9)= 1.26; % LowSigma_r
  ParamStore(10*cm_num, 10)= 8.32; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 4; % L_mean
  ParamStore(10*cm_num, 12)= NaN; % Delta_CapK
  ParamStore(10*cm_num, 12)= NaN; % Delta_LowK
  ParamStore(10*cm_num, 13)= NaN; % CapOmega
  ParamStore(10*cm_num, 14)= NaN; % h1
  ParamStore(10*cm_num, 15)= NaN; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
cm_num=2; % Residential NLOS
  ParamStore(cm_num, 1)= 2.44; % n
  ParamStore(cm_num, 2)= 86.0; % PLo
  ParamStore(cm_num, 3)= 6.2; % LowSigma_s
  ParamStore(cm_num, 4)= NaN; % CapLambda
  ParamStore(cm_num, 5)= NaN; % LowLambda
  ParamStore(cm_num, 6)= NaN; % CapGamma
  ParamStore(cm_num, 7)= NaN; % LowGamma
  ParamStore(cm_num, 8)= NaN; % LowSigma_c
  ParamStore(cm_num, 9)= NaN; % LowSigma_r
  ParamStore(cm_num, 10)= NaN; % LowSigma_phi
  ParamStore(cm_num, 11)= NaN; % L_mean
  ParamStore(cm_num, 12)= NaN; % Delta_CapK
  ParamStore(cm_num, 12)= NaN; % Delta_LowK
  ParamStore(cm_num, 13)= NaN; % CapOmega
  ParamStore(cm_num, 14)= NaN; % h1
  ParamStore(cm_num, 15)= NaN; % h2
  ParamStore(cm_num, 16)= NaN; % G_T
  ParamStore(cm_num, 17)= NaN; % G_R
  ParamStore(cm_num, 18)= 8.0; % fs
  ParamStore(cm_num, 19)= NaN; %CapK_los
cm_num=3.1; % Office LOS
  ParamStore(10*cm_num, 1)= 1.16; % n
  ParamStore(10*cm_num, 2)= 84.6; % PLo
  ParamStore(10*cm_num, 3)= 5.4; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.041; % CapLambda
  ParamStore(10*cm_num, 5)= 0.971; % LowLambda
  ParamStore(10*cm_num, 6)= 49.8; % CapGamma
  ParamStore(10*cm_num, 7)= 45.2; % LowGamma
  ParamStore(10*cm_num, 8)= 6.6; % LowSigma_c
  ParamStore(10*cm_num, 9)= 11.3; % LowSigma_r
  ParamStore(10*cm_num, 10)= 102; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 6; % L_mean
  ParamStore(10*cm_num, 12)= 27.2; % Delta_CapK
  ParamStore(10*cm_num, 12)= 21.9; % Delta_LowK
  ParamStore(10*cm_num, 13)= NaN; % CapOmega
  ParamStore(10*cm_num, 14)= 0.11; % h1
  ParamStore(10*cm_num, 15)= 0.11; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
cm_num=3.2; % Office LOS
  ParamStore(10*cm_num, 1)= 1.16; % n
  ParamStore(10*cm_num, 2)= 84.6; % PLo
  ParamStore(10*cm_num, 3)= 5.4; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.027; % CapLambda
  ParamStore(10*cm_num, 5)= 0.293; % LowLambda
  ParamStore(10*cm_num, 6)= 38.8; % CapGamma
  ParamStore(10*cm_num, 7)= 64.9; % LowGamma
  ParamStore(10*cm_num, 8)= 8.04; % LowSigma_c
  ParamStore(10*cm_num, 9)= 7.95; % LowSigma_r
  ParamStore(10*cm_num, 10)= 66.4; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 5; % L_mean
  ParamStore(10*cm_num, 12)= 22.8; % Delta_CapK
  ParamStore(10*cm_num, 12)= 11.4; % Delta_LowK
  ParamStore(10*cm_num, 13)= NaN; % CapOmega
  ParamStore(10*cm_num, 14)= 0.11; % h1
  ParamStore(10*cm_num, 15)= 0.11; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
cm_num=4; % Office NLOS
  ParamStore(cm_num, 1)= 3.74; % n
  ParamStore(cm_num, 2)= 56.1; % PLo
  ParamStore(cm_num, 3)= 8.6; % LowSigma_s
  ParamStore(cm_num, 4)= 0.07; % CapLambda
  ParamStore(cm_num, 5)= 1.88; % LowLambda
  ParamStore(cm_num, 6)= 19.44; % CapGamma
  ParamStore(cm_num, 7)= 0.42; % LowGamma
  ParamStore(cm_num, 8)= 1.82; % LowSigma_c
  ParamStore(cm_num, 9)= 1.88; % LowSigma_r
  ParamStore(cm_num, 10)= 9.1; % LowSigma_phi
  ParamStore(cm_num, 11)= 6; % L_mean
  ParamStore(cm_num, 12)= NaN; % Delta_CapK
  ParamStore(cm_num, 12)= NaN; % Delta_LowK
  ParamStore(cm_num, 13)= NaN; % CapOmega
  ParamStore(cm_num, 14)= NaN; % h1
  ParamStore(cm_num, 15)= NaN; % h2
  ParamStore(cm_num, 16)= NaN; % G_T
  ParamStore(cm_num, 17)= NaN; % G_R
  ParamStore(cm_num, 18)= 8.0; % fs
  ParamStore(cm_num, 19)= NaN; %CapK_los
cm_num=5; % Library LOS
  ParamStore(cm_num, 1)= NaN; % n
  ParamStore(cm_num, 2)= NaN; % PLo
  ParamStore(cm_num, 3)= NaN; % LowSigma_s
  ParamStore(cm_num, 4)= 0.25; % CapLambda
  ParamStore(cm_num, 5)= 4.0; % LowLambda
  ParamStore(cm_num, 6)= 12; % CapGamma
  ParamStore(cm_num, 7)= 7.0; % LowGamma
  ParamStore(cm_num, 8)= 5.0; % LowSigma_c
  ParamStore(cm_num, 9)= 6.0; % LowSigma_r
  ParamStore(cm_num, 10)= 10.0; % LowSigma_phi
  ParamStore(cm_num, 11)= 17; % L_mean
  ParamStore(cm_num, 12)= NaN; % Delta_CapK
  ParamStore(cm_num, 12)= NaN; % Delta_LowK
  ParamStore(cm_num, 13)= NaN; % CapOmega
  ParamStore(cm_num, 14)= NaN; % h1
  ParamStore(cm_num, 15)= NaN; % h2
  ParamStore(cm_num, 16)= NaN; % G_T
  ParamStore(cm_num, 17)= NaN; % G_R
  ParamStore(cm_num, 18)= 8.0; % fs
  ParamStore(cm_num, 19)= 8; %CapK_los
cm_num=6; % Library NLOS
  ParamStore(cm_num, 1)= NaN; % n
  ParamStore(cm_num, 2)= NaN; % PLo
  ParamStore(cm_num, 3)= NaN; % LowSigma_s
  ParamStore(cm_num, 4)= NaN; % CapLambda
  ParamStore(cm_num, 5)= NaN; % LowLambda
  ParamStore(cm_num, 6)= NaN; % CapGamma
  ParamStore(cm_num, 7)= NaN; % LowGamma
  ParamStore(cm_num, 8)= NaN; % LowSigma_c
  ParamStore(cm_num, 9)= NaN; % LowSigma_r
  ParamStore(cm_num, 10)= NaN; % LowSigma_phi
  ParamStore(cm_num, 11)= NaN; % L_mean
  ParamStore(cm_num, 12)= NaN; % Delta_CapK
  ParamStore(cm_num, 12)= NaN; % Delta_LowK
  ParamStore(cm_num, 13)= NaN; % CapOmega
  ParamStore(cm_num, 14)= NaN; % h1
  ParamStore(cm_num, 15)= NaN; % h2
  ParamStore(cm_num, 16)= NaN; % G_T
  ParamStore(cm_num, 17)= NaN; % G_R
  ParamStore(cm_num, 18)= 8.0; % fs
  ParamStore(cm_num, 19)= NaN; %CapK_los
cm_num=7; % Conference Room LOS
  ParamStore(cm_num, 1)= NaN; % n
  ParamStore(cm_num, 2)= NaN; % PLo
  ParamStore(cm_num, 3)= NaN; % LowSigma_s
  ParamStore(cm_num, 4)= NaN; % CapLambda
  ParamStore(cm_num, 5)= NaN; % LowLambda
  ParamStore(cm_num, 6)= NaN; % CapGamma
  ParamStore(cm_num, 7)= NaN; % LowGamma
  ParamStore(cm_num, 8)= NaN; % LowSigma_c
  ParamStore(cm_num, 9)= NaN; % LowSigma_r
  ParamStore(cm_num, 10)= NaN; % LowSigma_phi
  ParamStore(cm_num, 11)= NaN; % L_mean
  ParamStore(cm_num, 12)= NaN; % Delta_CapK
  ParamStore(cm_num, 12)= NaN; % Delta_LowK
  ParamStore(cm_num, 13)= NaN; % CapOmega
  ParamStore(cm_num, 14)= NaN; % h1
  ParamStore(cm_num, 15)= NaN; % h2
  ParamStore(cm_num, 16)= NaN; % G_T
  ParamStore(cm_num, 17)= NaN; % G_R
  ParamStore(cm_num, 18)= 8.0; % fs
  ParamStore(cm_num, 19)= NaN; %CapK_los
cm_num=8; % Conference Room NLOS
  ParamStore(cm_num, 1)= NaN; % n
  ParamStore(cm_num, 2)= NaN; % PLo
  ParamStore(cm_num, 3)= NaN; % LowSigma_s
  ParamStore(cm_num, 4)= NaN; % CapLambda
  ParamStore(cm_num, 5)= NaN; % LowLambda
  ParamStore(cm_num, 6)= NaN; % CapGamma
  ParamStore(cm_num, 7)= NaN; % LowGamma
  ParamStore(cm_num, 8)= NaN; % LowSigma_c
  ParamStore(cm_num, 9)= NaN; % LowSigma_r
  ParamStore(cm_num, 10)= NaN; % LowSigma_phi
  ParamStore(cm_num, 11)= NaN; % L_mean
  ParamStore(cm_num, 12)= NaN; % Delta_CapK
  ParamStore(cm_num, 12)= NaN; % Delta_LowK
  ParamStore(cm_num, 13)= NaN; % CapOmega
  ParamStore(cm_num, 14)= NaN; % h1
  ParamStore(cm_num, 15)= NaN; % h2
  ParamStore(cm_num, 16)= NaN; % G_T
  ParamStore(cm_num, 17)= NaN; % G_R
  ParamStore(cm_num, 18)= 8.0; % fs
  ParamStore(cm_num, 19)= NaN; %CapK_los
cm_num=9.1; % Desktop LOS
  ParamStore(10*cm_num, 1)= NaN; % n
  ParamStore(10*cm_num, 2)= NaN; % PLo
  ParamStore(10*cm_num, 3)= NaN; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.037; % CapLambda
  ParamStore(10*cm_num, 5)= 0.641; % LowLambda
  ParamStore(10*cm_num, 6)= 21.1; % CapGamma
  ParamStore(10*cm_num, 7)= 8.85; % LowGamma
  ParamStore(10*cm_num, 8)= 3.0; % LowSigma_c
  ParamStore(10*cm_num, 9)= 7.7; % LowSigma_r
  ParamStore(10*cm_num, 10)= 34.6; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 3; % L_mean
  ParamStore(10*cm_num, 12)= NaN; % Delta_CapK
  ParamStore(10*cm_num, 12)= NaN; % Delta_LowK
  ParamStore(10*cm_num, 13)= NaN; % CapOmega
  ParamStore(10*cm_num, 14)= NaN; % h1
  ParamStore(10*cm_num, 15)= NaN; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
cm_num=9.2; % Desktop LOS
  ParamStore(10*cm_num, 1)= NaN; % n
  ParamStore(10*cm_num, 2)= NaN; % PLo
  ParamStore(10*cm_num, 3)= NaN; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.047; % CapLambda
  ParamStore(10*cm_num, 5)= 0.373; % LowLambda
  ParamStore(10*cm_num, 6)= 22.3; % CapGamma
  ParamStore(10*cm_num, 7)= 17.2; % LowGamma
  ParamStore(10*cm_num, 8)= 7.27; % LowSigma_c
  ParamStore(10*cm_num, 9)= 4.42; % LowSigma_r
  ParamStore(10*cm_num, 10)= 38.1; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 3; % L_mean
  ParamStore(10*cm_num, 12)= NaN; % Delta_CapK
  ParamStore(10*cm_num, 12)= NaN; % Delta_LowK
  ParamStore(10*cm_num, 13)= NaN; % CapOmega
  ParamStore(10*cm_num, 14)= NaN; % h1
  ParamStore(10*cm_num, 15)= NaN; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
cm_num=9.3; % Desktop LOS
  ParamStore(10*cm_num, 1)= NaN; % n
  ParamStore(10*cm_num, 2)= NaN; % PLo
  ParamStore(10*cm_num, 3)= NaN; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1.72; % CapLambda
  ParamStore(10*cm_num, 5)= 3.14; % LowLambda
  ParamStore(10*cm_num, 6)= 4.01; % CapGamma
  ParamStore(10*cm_num, 7)= 0.58; % LowGamma
  ParamStore(10*cm_num, 8)= 2.7; % LowSigma_c
  ParamStore(10*cm_num, 9)= 1.9; % LowSigma_r
  ParamStore(10*cm_num, 10)= 14; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 14; % L_mean
  ParamStore(10*cm_num, 12)= NaN; % Delta_CapK
  ParamStore(10*cm_num, 12)= NaN; % Delta_LowK
  ParamStore(10*cm_num, 13)= NaN; % CapOmega
  ParamStore(10*cm_num, 14)= NaN; % h1
  ParamStore(10*cm_num, 15)= NaN; % h2
  ParamStore(10*cm_num, 16)= NaN; % G_T
  ParamStore(10*cm_num, 17)= NaN; % G_R
  ParamStore(10*cm_num, 18)= 8.0; % fs
  ParamStore(10*cm_num, 19)= NaN; %CapK_los
  
clear cm_num
  
save SvStore; % save all the S-V parameters for all channel models
    
return
