function [n, PLo, LowSigma_s, CapLambda, LowLambda, CapGamma, LowGamma, ...
    LowSigma_c, LowSigma_r, LowSigma_phi, L_mean, Delta_CapK, Delta_LowK, ...
    CapOmega, h1, h2, G_T, G_R, fs, CapK_los] = sv_params_TG3c( cm_num )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% Written by Sun Xu, Kim Chee Wee, B. Kannan & Francois Chin on 14/09/2004 
%
% Modified for 802.15.3c by Rick Roberts, 1 August 2006
%
% Return modified S-V model parameters for TG3c channel models
% n                 Path Loss Exponent
% PLo               Free Space Path Loss at Reference Distance 
% LowSigma_s        Standard Deviation of Path Loss Shadowing
% CapLambda         Cluster arrival rate (clusters per nsec)
% LowLambda         Ray arrival rate (rays per nsec)
% CapGamma          Cluster Decay Factor
% LowGamma          Ray Decay Factor
% LowSigma_c        Standard Deviation of Cluster Lognormal Fading Term (dB)
% LowSigma_r        Standard Deviation of Ray Lognormal Fading Term (dB)
% LowSignma_phi     Standard Deviation of the Ray Angle of Arrival
% L_mean            Mean number of Clusters
% Delta_CapK        LOS Rician Factor
% Delta_LowK        Cluster First Ray Factor
% CapOmega          Average Power of the First Ray of the First Cluster
% h1                Height of TX Antenna
% h2                Height of RX Antenna
% G_T               Gain of TX Antenna
% G_R               Gain of RX Antenna
% fs                Sampling Rate
% CapK_los          LOS K Factor
% nlos              Flag for non line of sight channel
%                       0 -> LOS
%                       1 -> NLOS with first arrival path starting at t ~= 0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% ParamStore definition:
%
% ParamStore(cm_num, ... 24 S-V parameters ...)
%
% dimensions: ParamStore (9, 24)
%
% ParamStore(cm_num, 1) <-- n
% ParamStore(cm_num, 2) <-- PLo
% ParamStore(cm_num, 3) <-- LowSigma_s
% ParamStore(cm_num, 4) <-- CapLambda
% ParamStore(cm_num, 5) <-- LowLambda
% ParamStore(cm_num, 6) <-- CapGamma
% ParamStore(cm_num, 7) <-- LowGamma
% ParamStore(cm_num, 8) <-- LowSigma_c
% ParamStore(cm_num, 9) <-- LowSigma_r
% ParamStore(cm_num, 10) <-- LowSigma_phi
% ParamStore(cm_num, 11) <-- L_mean
% ParamStore(cm_num, 12) <-- Delta_CapK
% ParamStore(cm_num, 12) <-- Delta_LowK
% ParamStore(cm_num, 13) <-- CapOmega
% ParamStore(cm_num, 14) <-- h1
% ParamStore(cm_num, 15) <-- h2
% ParamStore(cm_num, 16) <-- G_T
% ParamStore(cm_num, 17) <-- G_R
% ParamStore(cm_num, 18) <-- fs
% ParamStore(cm_num, 19) <-- CapK_los
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load SvStore; % load all the S-V parameters for all channel models

if mod(cm_num,1)~=0
    cm_num=10*cm_num;
end

n = ParamStore(cm_num, 1); % n
PLo = ParamStore(cm_num, 2); % PLo
LowSigma_s = ParamStore(cm_num, 3); % LowSigma_s
CapLambda = ParamStore(cm_num, 4); % CapLambda
LowLambda = ParamStore(cm_num, 5); % LowLambda
CapGamma = ParamStore(cm_num, 6); % CapGamma
LowGamma = ParamStore(cm_num, 7); % LowGamma
LowSigma_c = ParamStore(cm_num, 8); % LowSigma_c
LowSigma_r = ParamStore(cm_num, 9); % LowSigma_r
LowSigma_phi = ParamStore(cm_num, 10); % LowSigma_phi
L_mean = ParamStore(cm_num, 11); % L_mean
Delta_CapK = ParamStore(cm_num, 12); % Delta_CapK
Delta_LowK = ParamStore(cm_num, 12); % Delta_LowK
CapOmega = ParamStore(cm_num, 13); % CapOmega
h1 = ParamStore(cm_num, 14); % h1
h2 = ParamStore(cm_num, 15); % h2
G_T = ParamStore(cm_num, 16); % G_T
G_R = ParamStore(cm_num, 17); % G_R
fs = ParamStore(cm_num, 18); % fs
CapK_los = ParamStore(cm_num, 19); %CapK_los

return
